summaryrefslogtreecommitdiffstats
path: root/sys/dev/hwpmc
diff options
context:
space:
mode:
authorjhb <jhb@FreeBSD.org>2007-02-27 17:23:29 +0000
committerjhb <jhb@FreeBSD.org>2007-02-27 17:23:29 +0000
commit9081d442434a29679b0bafe249708a1bd48bbfde (patch)
treea0597a39b0c2d93af237d119ce7da913a8a44962 /sys/dev/hwpmc
parent3a7dab48bd395f66d9af79696af0534c63ae92f2 (diff)
downloadFreeBSD-src-9081d442434a29679b0bafe249708a1bd48bbfde.zip
FreeBSD-src-9081d442434a29679b0bafe249708a1bd48bbfde.tar.gz
Use pause() rather than tsleep() on stack variables and function pointers.
Diffstat (limited to 'sys/dev/hwpmc')
-rw-r--r--sys/dev/hwpmc/hwpmc_mod.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/sys/dev/hwpmc/hwpmc_mod.c b/sys/dev/hwpmc/hwpmc_mod.c
index c61314c..626e1ee 100644
--- a/sys/dev/hwpmc/hwpmc_mod.c
+++ b/sys/dev/hwpmc/hwpmc_mod.c
@@ -571,8 +571,8 @@ pmc_debugflags_sysctl_handler(SYSCTL_HANDLER_ARGS)
* We prevent further scheduling of the PMC by marking it as in
* state 'DELETED'. If the runcount of the PMC is non-zero then
* this PMC is currently running on a CPU somewhere. The thread
* doing the PMCRELEASE operation waits by repeatedly doing an
* tsleep() till the runcount comes to zero.
*
*/
@@ -638,7 +638,7 @@ pmc_select_cpu(int cpu)
/*
* Force a context switch.
*
* We do this by tsleep'ing for 1 tick -- invoking mi_switch() is not
* guaranteed to force a context switch.
*/
@@ -646,7 +646,7 @@ static void
pmc_force_context_switch(void)
{
- (void) tsleep((void *) pmc_force_context_switch, 0, "pmcctx", 1);
+ pause("pmcctx", 1);
}
/*
OpenPOWER on IntegriCloud
@@ -571,8 +571,8 @@ pmc_debugflags_sysctl_handler(SYSCTL_HANDLER_ARGS)
* state 'DELETED'. If the runcount of the PMC is non-zero then
* this PMC is currently running on a CPU somewhere. The thread
- * doing the PMCRELEASE operation waits by repeatedly doing an
- * tsleep() till the runcount comes to zero.
+ * doing the PMCRELEASE operation waits by repeatedly doing a
+ * pause() till the runcount comes to zero.
*
*/
@@ -638,7 +638,7 @@ pmc_select_cpu(int cpu)
* Force a context switch.
*
- * We do this by tsleep'ing for 1 tick -- invoking mi_switch() is not
+ * We do this by pause'ing for 1 tick -- invoking mi_switch() is not
* guaranteed to force a context switch.
*/